@@ -1,3 +1,5 @@
+# No logger planned to use here
+# pylint: disable=print-used,consider-using-with
 from __future__ import print_function
 
 import os
@@ -18,19 +20,14 @@ def main():
 
 def check_failed_dockerfile(scripts, lines_required=None):
     npm_bin = which('npm')
-    npm_bin_path = subprocess.check_output([npm_bin, 'bin']).\
-        decode('UTF-8').strip('\n') if npm_bin else ""
-    npm_bin_path_g = subprocess.check_output([npm_bin, 'bin', '-g']).\
-        decode('UTF-8').strip('\n') if npm_bin else ""
+    npm_bin_path = subprocess.check_output([npm_bin, 'bin']).decode('UTF-8').strip('\n') if npm_bin else ""
+    npm_bin_path_g = subprocess.check_output([npm_bin, 'bin', '-g']).decode('UTF-8').strip('\n') if npm_bin else ""
     lint_bin_name = 'dockerfile_lint'
-    lint_bin = which(lint_bin_name) or \
-        which(lint_bin_name, path=npm_bin_path + os.pathsep + npm_bin_path_g)
+    lint_bin = which(lint_bin_name) or which(lint_bin_name, path=npm_bin_path + os.pathsep + npm_bin_path_g)
     assert lint_bin, "'%s' not found." % lint_bin_name
     for script in scripts:
         fname_dkr = os.path.join(script, 'Dockerfile')
-        pipe = subprocess.Popen([lint_bin, "-f", fname_dkr],
-                                stderr=subprocess.STDOUT,
-                                stdout=subprocess.PIPE)
+        pipe = subprocess.Popen([lint_bin, "-f", fname_dkr], stderr=subprocess.STDOUT, stdout=subprocess.PIPE)
         output = pipe.stdout.read().decode('utf-8')
         assert 'Check passed' in output, fname_dkr
         print("Check dockerfile output", output)
@@ -46,32 +43,25 @@ def check_failed_dockerfile(scripts, lines_required=None):
 
 def test_main():
     # TODO: fix duplicated code
-    dirname_example = os.path.join(
-        os.path.dirname(os.path.realpath(__file__)), '..', 'examples')
+    dirname_example = os.path.join(os.path.dirname(os.path.realpath(__file__)), '..', 'examples')
     argv = ['travis2docker', 'foo', 'bar', '--no-clone']
-    sources_py = ("source ${REPO_REQUIREMENTS}/virtualenv/"
-                  "python2.7/bin/activate")
+    sources_py = "source ${REPO_REQUIREMENTS}/virtualenv/" + "python2.7/bin/activate"
     sources_js = "source ${REPO_REQUIREMENTS}/virtualenv/nodejs/bin/activate"
     lines_required = [
         'RUN /bin/bash -c "{source_py} && {source_js} '
-        '&& source /rvm_env.sh && /install"'.
-        format(source_py=sources_py, source_js=sources_js),
+        '&& source /rvm_env.sh && /install"'.format(source_py=sources_py, source_js=sources_js),
         'ENTRYPOINT /entrypoint.sh',
     ]
 
     example = os.path.join(dirname_example, 'example_1.yml')
-    sys.argv = argv + ['--travis-yml-path', example,
-                       '--add-rcfile=%s,%s' % (example, dirname_example)]
+    sys.argv = argv + ['--travis-yml-path', example, '--add-rcfile=%s,%s' % (example, dirname_example)]
     scripts = main()
     assert len(scripts) == 1, 'Scripts returned should be 1 for %s' % example
     check_failed_dockerfile(scripts, lines_required)
-    assert os.path.isdir(
-        os.path.join(scripts[0], os.path.basename(dirname_example)))
-    assert os.path.isfile(
-        os.path.join(scripts[0], os.path.basename(example)))
+    assert os.path.isdir(os.path.join(scripts[0], os.path.basename(dirname_example)))
+    assert os.path.isfile(os.path.join(scripts[0], os.path.basename(example)))
 
-    sys.argv = argv + ['--travis-yml-path', example,
-                       '--docker-image', 'quay.io/travisci/travis-python']
+    sys.argv = argv + ['--travis-yml-path', example, '--docker-image', 'quay.io/travisci/travis-python']
     scripts = main()
     assert len(scripts) == 1, 'Scripts returned should be 1 for %s' % example
     check_failed_dockerfile(scripts, ['FROM quay.io/travisci/travis-python'])
@@ -127,27 +117,28 @@ def test_main():
     url = 'https://github.com/Vauxoo/travis2docker.git'
     sys.argv = ['travis2docker', url, 'master']
     scripts = main()
-    sources_py = ("source ${REPO_REQUIREMENTS}/virtualenv/"
-                  "python3.5/bin/activate")
+    sources_py = "source ${REPO_REQUIREMENTS}/virtualenv/" + "python3.5/bin/activate"
     lines_required.pop(0)
     lines_required.append(
         'RUN /bin/bash -c "{source_py} && {source_js} && '
         'source /rvm_env.sh && '
-        '/before_install && /install"'.
-        format(source_py=sources_py, source_js=sources_js),
+        '/before_install && /install"'.format(source_py=sources_py, source_js=sources_js),
     )
-    check_failed_dockerfile(scripts, lines_required + [
-        'ENV TRAVIS_REPO_SLUG=Vauxoo/travis2docker'])
+    check_failed_dockerfile(scripts, lines_required + ['ENV TRAVIS_REPO_SLUG=Vauxoo/travis2docker'])
 
     sys.argv = ['travis2docker', url, 'pull/54']
     scripts = main()
-    check_failed_dockerfile(scripts, lines_required + [
-        'ENV TRAVIS_REPO_SLUG=Vauxoo/travis2docker'])
+    check_failed_dockerfile(scripts, lines_required + ['ENV TRAVIS_REPO_SLUG=Vauxoo/travis2docker'])
 
-    sys.argv += ['--build-env-args', 'BUILD_ENV1',
-                 '--build-env-args', 'BUILD_ENV2']
+    sys.argv += ['--build-env-args', 'BUILD_ENV1', '--build-env-args', 'BUILD_ENV2']
     scripts = main()
-    check_failed_dockerfile(scripts, lines_required + [
-        'ARG BUILD_ENV1', 'ENV BUILD_ENV1=$BUILD_ENV1',
-        'ARG BUILD_ENV2', 'ENV BUILD_ENV2=$BUILD_ENV2',
-    ])
+    check_failed_dockerfile(
+        scripts,
+        lines_required
+        + [
+            'ARG BUILD_ENV1',
+            'ENV BUILD_ENV1=$BUILD_ENV1',
+            'ARG BUILD_ENV2',
+            'ENV BUILD_ENV2=$BUILD_ENV2',
+        ],
+    )
